@@ -38,7 +38,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 
 our @attr = qw
@@ -159,6 +159,20 @@ __END__
 
  DBIx::DBH - Perl extension for simplifying database connections
 
+=head1 SYNOPSIS
+
+ use DBIx::DBH;
+
+ my %opt = (tty => 1) ;
+ my %dat = ( 
+     driver => 'Pg',
+     dbname => 'db_terry',
+     user => 'terry',
+     password => 'markso'
+ );
+
+ my $dbh = DBIx::DBH::connect(%dat, %opt) ;
+
 =head1 ABSTRACT
 
 DBIx::DBH is designed to facilitate and validate the process of creating 
